@@ -8,7 +8,7 @@ from pytest import fixture  # type: ignore
 
 @fixture
 def in_sandbox() -> Generator:
-    sandbox_dir = (Path(".") / "sandbox").absolute()
+    sandbox_dir = Path("/tmp") / "sandbox"
     if sandbox_dir.exists():
         shutil.rmtree(str(sandbox_dir))
 
